@@ -28,7 +28,8 @@
 #  $Id$
 
 # combo styles
-package cs;
+package 
+    cs;
 use constant Simple       =>  0;
 use constant DropDown     =>  1;
 use constant DropDownList =>  2;
@@ -789,6 +790,25 @@ Mapped onto the edit widget's C<text> property.
 
 =back
 
+=head2 Events
+
+=over
+
+=item Change
+
+Triggered with ComboBox value is changed.
+
+=item List events
+
+ComboBox forwards C<SelectItem> and C<DrawItem> events from the list box, and
+these are executed in the List's context (therefore $self there is not
+ComboBox, but the ComboBox->List). If you use C<SelectItem> you probably need
+C<Change> instead.
+
+See more in L<Prima::Lists>.
+
+=back
+
 =head2 Exported names
 
 =over
