@@ -127,7 +127,21 @@ sub init
 		if ( $images[0]) {
 			@imageSize = $images[0]-> size;
 		} else {
-			@imageSize = (0,0);
+			# if compiled without gif support
+			@imageSize = (11,11);
+			for my $i (0,1) {
+				$images[$i] = Prima::DeviceBitmap->new(
+					width     => $imageSize[0],
+					height    => $imageSize[1],
+					backColor => cl::White,
+					color     => cl::Gray,
+				);
+				$images[$i]->clear;
+				$images[$i]->rectangle(0,0,10,10);
+				$images[$i]->color(cl::Black);
+				$images[$i]->line( 2, 5, 8, 5 );
+			}
+			$images[1]->line( 5, 2, 5, 8);
 		}
 	}
 	for ( qw( topItem focusedItem))
@@ -2489,7 +2503,7 @@ class.
 Provides a standard widget with the item tree mapped to the directory
 structure, so each item is mapped to a directory. Depending on the type 
 of the host OS, there is either single root directory ( unix ), or
-one or more disk drive root items ( win32, os2 ).
+one or more disk drive root items ( win32 ).
 
 The format of a node is defined as follows:
 
@@ -2549,7 +2563,7 @@ Runtime-only property. Selects current file system path.
 Selects if the directories with the first dot character
 are shown the tree view. The treatment of the dot-prefixed names
 as hidden is traditional to unix, and is of doubtful use under
-win32 and os2.
+win32.
 
 Default value: 0
 
